<%inherit file="basewithmenu.html" /> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Automatic classification of documents

Classifier:

Select the classifier to produce an automatic classification of the dataset.

The automatic classification is performed by a background process (showing 'running' in the status as it goes on).

Once completed the dataset with the automatically assigned labels can be downloaded as a CSV file.

Processing

×

### Live classification of documents

Classifier:

Processing

×

### Delete a classification

Classification to delete:

Processing